==> react-native-selectmultiple-button-0.0.18.tgz: package/libraries/SelectMultipleButton.js <==
/*
 * @Author: Young
 * DSHARP
 * @flow 
 * @Date: 2018-02-06 13:54:25 
 * @Last Modified by: Young
 * @Last Modified time: 2018-02-09 17:15:52
 */
import React, { Component } from 'react'
import PropTypes from 'prop-types'
import {
  View,
  Text,
  TouchableWithoutFeedback,
  Alert,
  StyleSheet,
} from 'react-native'

const ios_blue = '#007AFF'

export default class SelectMultipleButton extends Component {

  static propTypes = {
    selectMultiple: PropTypes.bool,

    selected: PropTypes.bool,

    value: PropTypes.oneOfType(
      [
        PropTypes.string,
        PropTypes.number
      ]
    ).isRequired,
    displayValue: PropTypes.oneOfType(
      [
        PropTypes.string,
        PropTypes.number
      ]
    ),

    highLightStyle: PropTypes.shape({
      borderColor: PropTypes.string.isRequired,
      backgroundColor: PropTypes.string.isRequired,
      textColor: PropTypes.string.isRequired,
      borderTintColor: PropTypes.string.isRequired,
      backgroundTintColor: PropTypes.string.isRequired,
      textTintColor: PropTypes.string.isRequired,
    }),

    buttonViewStyle: PropTypes.object,
    textStyle: PropTypes.object,
    singleTap: PropTypes.func,

  }

  static defaultProps = {
    selected: false,
    selectMultiple: true,
    highLightStyle: {
      borderColor: 'gray',
      backgroundColor: 'transparent',
      textColor: 'gray',
      borderTintColor: ios_blue,
      backgroundTintColor: 'transparent',
      textTintColor: ios_blue,
    },

    singleTap: (valueTap) => { },
  }

  constructor(props) {
    super(props)
    this.state = {
      selected: false,
    }
  }

  componentDidMount() {
    this.setState({
      selected: this.props.selected,
    })
  }

  componentWillReceiveProps(nextProps) {
    if (this.props.selected !== nextProps.selected) {
      this.setState({
        selected: nextProps.selected
      })
    }
  }

  render() {
    return (
      <TouchableWithoutFeedback
        onPress={() => {
          if (this.props.selectMultiple) {
            this.setState({ selected: !this.state.selected })
            this.props.singleTap(this.props.value)
          } else {
            if (!this.state.selected) {
              this.setState({ selected: !this.state.selected })
              this.props.singleTap(this.props.value)
            }
          }

        }
        }>
        <View
          style={
            [
              styles.button,
              this.props.buttonViewStyle,
              {
                borderColor: this.state.selected ? this.props.highLightStyle.borderTintColor : this.props.highLightStyle.borderColor,
                backgroundColor: this.state.selected ? this.props.highLightStyle.backgroundTintColor : this.props.highLightStyle.backgroundColor,
              }
            ]
          }>
          <Text style={
            [
              styles.text,
              this.props.textStyle,
              { color: this.state.selected ? this.props.highLightStyle.textTintColor : this.props.highLightStyle.textColor }
            ]
          }>
            {this.props.displayValue === undefined ? this.props.value : this.props.displayValue}
          </Text>
        </View>
      </TouchableWithoutFeedback >
    )
  }
}

const styles = StyleSheet.create({
  button: {
    margin: 5,
    borderRadius: 3,
    alignItems: 'center',
    justifyContent: 'center',
    borderWidth: 1
  },
  text: {
    textAlign: 'center',
    marginTop: 5,
    marginBottom: 5,
    marginLeft: 10,
    marginRight: 10,
  }
})

==> react-native-selectmultiple-button-0.0.84.tgz: package/libraries/SelectMultipleButton.js <==
/*
 * @Author: Young
 * DSHARP
 * @flow 
 * @Date: 2018-02-06 13:54:25 
 * @Last Modified by: Young
 * @Last Modified time: 2018-02-12 10:06:05
 */
import React, { Component } from 'react'
import PropTypes from 'prop-types'
import {
  View,
  Text,
  TouchableWithoutFeedback,
  Alert,
  StyleSheet,
} from 'react-native'

const ios_blue = '#007AFF'

export default class SelectMultipleButton extends Component {

  static propTypes = {
    multiple: PropTypes.bool,

    selected: PropTypes.bool,

    value: PropTypes.oneOfType(
      [
        PropTypes.string,
        PropTypes.number
      ]
    ).isRequired,
    displayValue: PropTypes.oneOfType(
      [
        PropTypes.string,
        PropTypes.number
      ]
    ),

    highLightStyle: PropTypes.shape({
      borderColor: PropTypes.string.isRequired,
      backgroundColor: PropTypes.string.isRequired,
      textColor: PropTypes.string.isRequired,
      borderTintColor: PropTypes.string.isRequired,
      backgroundTintColor: PropTypes.string.isRequired,
      textTintColor: PropTypes.string.isRequired,
    }),

    buttonViewStyle: PropTypes.object,
    textStyle: PropTypes.object,
    singleTap: PropTypes.func,

  }

  static defaultProps = {
    selected: false,
    multiple: true,
    highLightStyle: {
      borderColor: 'gray',
      backgroundColor: 'transparent',
      textColor: 'gray',
      borderTintColor: ios_blue,
      backgroundTintColor: 'transparent',
      textTintColor: ios_blue,
    },

    singleTap: (valueTap) => { },
  }

  constructor(props) {
    super(props)
    this.state = {
      selected: false,
    }
  }

  componentDidMount() {
    this.setState({
      selected: this.props.selected,
    })
  }

  componentWillReceiveProps(nextProps) {
    if (this.props.selected !== nextProps.selected) {
      this.setState({
        selected: nextProps.selected
      })
    }
  }

  render() {
    return (
      <TouchableWithoutFeedback
        onPress={() => {
          if (this.props.multiple) {
            this.setState({ selected: !this.state.selected })
            this.props.singleTap(this.props.value)
          } else {
            if (!this.state.selected) {
              this.setState({ selected: !this.state.selected })
              this.props.singleTap(this.props.value)
            }
          }

        }
        }>
        <View
          style={
            [
              styles.button,
              this.props.buttonViewStyle,
              {
                borderColor: this.state.selected ? this.props.highLightStyle.borderTintColor : this.props.highLightStyle.borderColor,
                backgroundColor: this.state.selected ? this.props.highLightStyle.backgroundTintColor : this.props.highLightStyle.backgroundColor,
              }
            ]
          }>
          <Text style={
            [
              styles.text,
              this.props.textStyle,
              { color: this.state.selected ? this.props.highLightStyle.textTintColor : this.props.highLightStyle.textColor }
            ]
          }>
            {this.props.displayValue === undefined ? this.props.value : this.props.displayValue}
          </Text>
        </View>
      </TouchableWithoutFeedback >
    )
  }
}

const styles = StyleSheet.create({
  button: {
    margin: 5,
    borderRadius: 3,
    alignItems: 'center',
    justifyContent: 'center',
    borderWidth: 1
  },
  text: {
    textAlign: 'center',
    marginTop: 5,
    marginBottom: 5,
    marginLeft: 10,
    marginRight: 10,
  }
})
